package com.pokkt.wrapper.thirdparty.AdMob;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.util.Log;

import com.google.android.gms.ads.AdRequest;
import com.google.android.gms.ads.mediation.MediationAdRequest;
import com.google.android.gms.ads.reward.RewardItem;
import com.google.android.gms.ads.reward.mediation.MediationRewardedVideoAdAdapter;
import com.google.android.gms.ads.reward.mediation.MediationRewardedVideoAdListener;
import com.pokkt.PokktAds;
import com.pokkt.sdk.models.PokktAdPlayerViewConfig;

import org.json.JSONObject;

public class PokktCustomRewardedVideo implements MediationRewardedVideoAdAdapter, PokktAds.VideoAd.VideoAdDelegate {

    private final String TAG = "PokktAdMobWrapperVideo";
    private MediationRewardedVideoAdListener videoAdListener;
    private String screenName = "Test";
    private boolean isInitialized;
    private String appId = "Default";
    private String secKey = "";
    private String thirdPartyUserid = "12345";
    private String rewardCurrency = "";
    private boolean isDebug = true;
    private int skipTime = 0;

    @Override
    public void initialize(Context context, MediationAdRequest mediationAdRequest, String serverParameter, MediationRewardedVideoAdListener listener, Bundle bundle, Bundle bundle1) {
        try {
            if (bundle != null) {
                String parameters = bundle.getString("parameter");
                if (!TextUtils.isEmpty(parameters)) {
                    JSONObject serverExtraObj = new JSONObject(parameters);
                    screenName = serverExtraObj.optString("POKKT_SCREEN_NAME", "Test");
                    appId = serverExtraObj.optString("POKKT_APP_ID", "");
                    secKey = serverExtraObj.optString("POKKT_SEC_KEY", "");
                    thirdPartyUserid = serverExtraObj.optString("POKKT_THIRD_PARTY_USERID", "12345");
                    rewardCurrency = serverExtraObj.optString("POKKT_REWARD_NAME", "");
                    isDebug = serverExtraObj.optBoolean("POKKT_DEBUG", true);
                    skipTime = serverExtraObj.optInt("POKKT_SKIP_TIME", 0);
                }
            }
        } catch (Throwable t) {
            if (isDebug) {
                Log.e(TAG, "Failed to parse server parameters: " + serverParameter);
            }
        }
        if (TextUtils.isEmpty(appId) || TextUtils.isEmpty(secKey)) {
            if (isDebug) {
                Log.e(TAG, "Invalid details. Abort request");
            }
            isInitialized = false;
            return;
        }
        if (isDebug) {
            Log.d(TAG, "Initialize wrapper");
        }
        videoAdListener = listener;
        PokktAds.setPokktConfig(appId, secKey, (Activity) context);
        PokktAds.setThirdPartyUserId(thirdPartyUserid);
        PokktAds.Debugging.shouldDebug(context, isDebug);
        PokktAds.VideoAd.setDelegate(this);
        //Set Player Ad Config
        PokktAdPlayerViewConfig config = new PokktAdPlayerViewConfig();
        config.setDefaultSkipTime(skipTime);
        PokktAds.setAdPlayerViewConfig(config);
        isInitialized = true;
    }

    @Override
    public void loadAd(MediationAdRequest mediationAdRequest, Bundle bundle, Bundle bundle1) {
        if (isDebug) {
            Log.i(TAG, "Load ad from wrapper");
        }
        PokktAds.VideoAd.cacheRewarded(screenName);
    }

    @Override
    public void showVideo() {
        if (isDebug) {
            Log.i(TAG, "Show video from wrapper");
        }
        PokktAds.VideoAd.showRewarded(screenName);
    }

    @Override
    public boolean isInitialized() {
        return isInitialized;
    }

    @Override
    public void onDestroy() {

    }

    @Override
    public void onPause() {

    }

    @Override
    public void onResume() {

    }

    @Override
    public void videoAdCachingCompleted(String screenName, boolean isRewarded, double rewardValue) {
        if (isDebug) {
            Log.i(TAG, " video caching completed");
        }
        if (PokktCustomRewardedVideo.this.videoAdListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomRewardedVideo.this.videoAdListener.onAdLoaded(PokktCustomRewardedVideo.this);
                }
            });
        }
    }

    @Override
    public void videoAdCachingFailed(String screenName, boolean isRewaded, String errorMessage) {
        if (isDebug) {
            Log.i(TAG, " video caching failed " + errorMessage);
        }
        if (PokktCustomRewardedVideo.this.videoAdListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomRewardedVideo.this.videoAdListener.onAdFailedToLoad(PokktCustomRewardedVideo.this, AdRequest.ERROR_CODE_NO_FILL);
                }
            });
        }
    }

    @Override
    public void videoAdDisplayed(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, " video displayed");
        }
        if (PokktCustomRewardedVideo.this.videoAdListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomRewardedVideo.this.videoAdListener.onAdOpened(PokktCustomRewardedVideo.this);
                    PokktCustomRewardedVideo.this.videoAdListener.onVideoStarted(PokktCustomRewardedVideo.this);
                }
            });
        }
    }

    @Override
    public void videoAdFailedToShow(String screenName, boolean isRewarded, String errorMessage) {
        if (isDebug) {
            Log.i(TAG, " video failed to show " + errorMessage);
        }
        if (PokktCustomRewardedVideo.this.videoAdListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomRewardedVideo.this.videoAdListener.onAdClosed(PokktCustomRewardedVideo.this);
                }
            });
        }
    }

    @Override
    public void videoAdClosed(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, " video closed");
        }
        if (PokktCustomRewardedVideo.this.videoAdListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomRewardedVideo.this.videoAdListener.onAdClosed(PokktCustomRewardedVideo.this);
                }
            });
        }
    }

    @Override
    public void videoAdSkipped(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, " video skipped");
        }
    }

    @Override
    public void videoAdCompleted(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, " video completed");
        }
    }

    @Override
    public void videoAdGratified(String screenName, boolean isRewarded, final double rewardValue) {
        if (isDebug) {
            Log.i(TAG, " video gratified");
        }
        if (PokktCustomRewardedVideo.this.videoAdListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomRewardedVideo.this.videoAdListener.onRewarded(PokktCustomRewardedVideo.this, new RewardItem() {
                        @Override
                        public String getType() {
                            return rewardCurrency;
                        }

                        @Override
                        public int getAmount() {
                            return (int) rewardValue;
                        }
                    });
                }
            });
        }
    }

    @Override
    public void videoAdAvailabilityStatus(String screenName, boolean isRewarded, boolean availability) {
        if (isDebug) {
            Log.i(TAG, " video available");
        }
    }
}
